.. aisim documentation master file, created by
   sphinx-quickstart on Tue Jun  2 16:32:28 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

AISim ‒ Simulations for light-pulse atom interferometry
==========================================================

AISim is a Python package for simulating light-pulse atom
interferometers.

It uses dedicated objects to model the lasers beams, the atomic ensemble
and the detection system and store experimental parameters in a neat
way. After you define these objects you can use built-in propagators to
simulate internal and external degrees of freedom of cold atoms.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   install.rst
   usage.rst
   aisim.rst
   dev.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
